summaryrefslogtreecommitdiffstats
path: root/kpresenter
diff options
context:
space:
mode:
Diffstat (limited to 'kpresenter')
-rw-r--r--kpresenter/KPrAutoformObject.cpp4
-rw-r--r--kpresenter/KPrBackDia.cpp6
-rw-r--r--kpresenter/KPrBackground.cpp2
-rw-r--r--kpresenter/KPrCanvas.cpp28
-rw-r--r--kpresenter/KPrDocument.cpp6
-rw-r--r--kpresenter/KPrEffectDia.cpp22
-rw-r--r--kpresenter/KPrMSPresentationSetup.cpp10
-rw-r--r--kpresenter/KPrNoteBar.cpp2
-rw-r--r--kpresenter/KPrPBPreview.cpp4
-rw-r--r--kpresenter/KPrPgConfDia.cpp2
-rw-r--r--kpresenter/KPrPixmapObject.cpp2
-rw-r--r--kpresenter/KPrPresDurationDia.cpp2
-rw-r--r--kpresenter/KPrSideBar.cpp2
-rw-r--r--kpresenter/KPrSideBar.h4
-rw-r--r--kpresenter/KPrTextObject.cpp8
-rw-r--r--kpresenter/KPrTextProperty.cpp2
-rw-r--r--kpresenter/KPrTransEffectDia.cpp4
-rw-r--r--kpresenter/KPrView.cpp40
-rw-r--r--kpresenter/KPrWebPresentation.cpp42
-rw-r--r--kpresenter/autoformEdit/AFChoose.cpp4
-rw-r--r--kpresenter/generalpropertyui.ui2
-rw-r--r--kpresenter/imageEffectBase.ui40
-rw-r--r--kpresenter/insertpagedia.ui2
-rw-r--r--kpresenter/penstyle.ui2
-rw-r--r--kpresenter/picturepropertyui.ui2
-rw-r--r--kpresenter/piepropertyui.ui2
-rw-r--r--kpresenter/polygonpropertyui.ui2
-rw-r--r--kpresenter/rectpropertyui.ui6
-rw-r--r--kpresenter/rotationpropertyui.ui6
-rw-r--r--kpresenter/shadowdialog.ui4
-rw-r--r--kpresenter/slidetransitionwidget.ui4
31 files changed, 134 insertions, 134 deletions
diff --git a/kpresenter/KPrAutoformObject.cpp b/kpresenter/KPrAutoformObject.cpp
index 88245f6d..60c5cdcb 100644
--- a/kpresenter/KPrAutoformObject.cpp
+++ b/kpresenter/KPrAutoformObject.cpp
@@ -237,8 +237,8 @@ void KPrAutoformObject::paint( TQPainter* _painter, KoTextZoomHandler *_zoomHand
{
if ( angle == 0 || angle==360 )
{
- //int ox = _painter->viewport().x() + static_cast<int>( _painter->tqworldMatrix().dx() );
- //int oy = _painter->viewport().y() + static_cast<int>( _painter->tqworldMatrix().dy() );
+ //int ox = _painter->viewport().x() + static_cast<int>( _painter->worldMatrix().dx() );
+ //int oy = _painter->viewport().y() + static_cast<int>( _painter->worldMatrix().dy() );
TQPointArray pntArray3 = pntArray2.copy();
_painter->save();
diff --git a/kpresenter/KPrBackDia.cpp b/kpresenter/KPrBackDia.cpp
index b616f802..b404231d 100644
--- a/kpresenter/KPrBackDia.cpp
+++ b/kpresenter/KPrBackDia.cpp
@@ -175,7 +175,7 @@ KPrBackDialog::KPrBackDialog( TQWidget* parent, const char* name,
picTab->setMargin( 5 );
TQLabel *l = new TQLabel( i18n( "View mode:" ), picTab );
- l->setFixedHeight( l->tqsizeHint().height() );
+ l->setFixedHeight( l->sizeHint().height() );
picView = new TQComboBox( false, picTab );
picView->insertItem( i18n( "Scaled" ) );
@@ -186,10 +186,10 @@ KPrBackDialog::KPrBackDialog( TQWidget* parent, const char* name,
this, TQT_SLOT( updateConfiguration() ) );
picChooseLabel = new TQLabel( i18n("&Location:"), picTab );
- picChooseLabel->setFixedHeight( picChooseLabel->tqsizeHint().height() );
+ picChooseLabel->setFixedHeight( picChooseLabel->sizeHint().height() );
picChoose = new KURLRequester( picTab, "picChoose" );
- picChoose->setFixedHeight( picChoose->tqsizeHint().height() );
+ picChoose->setFixedHeight( picChoose->sizeHint().height() );
picChoose->setMode( KFile::ExistingOnly );
connect( picChoose, TQT_SIGNAL( openFileDialog( KURLRequester * ) ),
TQT_SLOT( aboutToSelectPic() ) );
diff --git a/kpresenter/KPrBackground.cpp b/kpresenter/KPrBackground.cpp
index 66102045..484a5eab 100644
--- a/kpresenter/KPrBackground.cpp
+++ b/kpresenter/KPrBackground.cpp
@@ -282,7 +282,7 @@ void KPrBackGround::loadOasis(KoOasisContext & context )
strExtension=href.mid(result+1); // As we are using KoPicture, the extension should be without the dot.
}
TQString filename(href);
- const KoPictureKey key(filename, TQDateTime::tqcurrentDateTime(Qt::UTC));
+ const KoPictureKey key(filename, TQDateTime::currentDateTime(Qt::UTC));
backPicture.setKey(key);
KoStore* store = context.store();
diff --git a/kpresenter/KPrCanvas.cpp b/kpresenter/KPrCanvas.cpp
index c43faed3..e5e97785 100644
--- a/kpresenter/KPrCanvas.cpp
+++ b/kpresenter/KPrCanvas.cpp
@@ -4602,8 +4602,8 @@ void KPrCanvas::moveObjectsByKey( int x, int y )
m_moveSnapDiff = KoPoint( 0, 0 );
- KoGuides::SnaptqStatus snaptqStatus = KoGuides::SNAP_NONE;
- m_gl.snapToGuideLines( movedRect, KEY_SNAP_DISTANCE, snaptqStatus, m_moveSnapDiff );
+ KoGuides::SnapStatus snapStatus = KoGuides::SNAP_NONE;
+ m_gl.snapToGuideLines( movedRect, KEY_SNAP_DISTANCE, snapStatus, m_moveSnapDiff );
move += m_moveSnapDiff;
}
@@ -4672,7 +4672,7 @@ void KPrCanvas::moveObjectsByMouse( KoPoint &pos, bool keepXorYunchanged )
move -= m_moveSnapDiff;
m_moveSnapDiff = KoPoint( 0, 0 ); // needed if all snapping is off
- KoGuides::SnaptqStatus snaptqStatus = KoGuides::SNAP_NONE;
+ KoGuides::SnapStatus snapStatus = KoGuides::SNAP_NONE;
if ( snapToGrid )
{
@@ -4680,12 +4680,12 @@ void KPrCanvas::moveObjectsByMouse( KoPoint &pos, bool keepXorYunchanged )
- movedRect.topLeft().x() );
m_moveSnapDiff.setY( tqRound( movedRect.topLeft().y() / doc->getGridY()) * doc->getGridY()
- movedRect.topLeft().y() );
- snaptqStatus = KoGuides::SNAP_BOTH;
+ snapStatus = KoGuides::SNAP_BOTH;
}
if ( snapToGuideLines )
{
- m_gl.snapToGuideLines( movedRect, MOUSE_SNAP_DISTANCE, snaptqStatus, m_moveSnapDiff );
+ m_gl.snapToGuideLines( movedRect, MOUSE_SNAP_DISTANCE, snapStatus, m_moveSnapDiff );
}
move += m_moveSnapDiff;
@@ -4745,7 +4745,7 @@ void KPrCanvas::resizeObject( ModifyType _modType, const KoPoint & point, bool k
TQRect oldBoundingRect( m_view->zoomHandler()->zoomRect( kpobject->getRepaintRect() ) );
KoRect objRect = kpobject->getRealRect();
- KoGuides::SnaptqStatus snaptqStatus( KoGuides::SNAP_NONE );
+ KoGuides::SnapStatus snapStatus( KoGuides::SNAP_NONE );
bool left = false;
bool right = false;
@@ -4754,22 +4754,22 @@ void KPrCanvas::resizeObject( ModifyType _modType, const KoPoint & point, bool k
if ( _modType == MT_RESIZE_UP || _modType == MT_RESIZE_LU || _modType == MT_RESIZE_RU )
{
top = true;
- snaptqStatus |= KoGuides::SNAP_HORIZ;
+ snapStatus |= KoGuides::SNAP_HORIZ;
}
if ( _modType == MT_RESIZE_DN || _modType == MT_RESIZE_LD || _modType == MT_RESIZE_RD )
{
bottom = true;
- snaptqStatus |= KoGuides::SNAP_HORIZ;
+ snapStatus |= KoGuides::SNAP_HORIZ;
}
if ( _modType == MT_RESIZE_LF || _modType == MT_RESIZE_LU || _modType == MT_RESIZE_LD )
{
left = true;
- snaptqStatus |= KoGuides::SNAP_VERT;
+ snapStatus |= KoGuides::SNAP_VERT;
}
if ( _modType == MT_RESIZE_RT || _modType == MT_RESIZE_RU || _modType == MT_RESIZE_RD )
{
right = true;
- snaptqStatus |= KoGuides::SNAP_VERT;
+ snapStatus |= KoGuides::SNAP_VERT;
}
double newLeft = objRect.left();
@@ -4931,7 +4931,7 @@ void KPrCanvas::resizeObject( ModifyType _modType, const KoPoint & point, bool k
{
sp.setY( rect.bottom() );
}
- m_gl.repaintSnapping( sp, snaptqStatus );
+ m_gl.repaintSnapping( sp, snapStatus );
}
_tqrepaint( oldBoundingRect );
@@ -5553,18 +5553,18 @@ KoPoint KPrCanvas::snapPoint( KoPoint &pos, bool repaintSnapping )
bool snapToGuideLines = doc->showGuideLines() && !m_disableSnapping;
KoPoint snapDiff = KoPoint( 0, 0 ); // needed if all snapping is off
- KoGuides::SnaptqStatus snaptqStatus = KoGuides::SNAP_NONE;
+ KoGuides::SnapStatus snapStatus = KoGuides::SNAP_NONE;
if ( snapToGrid )
{
snapDiff.setX( tqRound( sp.x() / doc->getGridX()) * doc->getGridX() - sp.x() );
snapDiff.setY( tqRound( sp.y() / doc->getGridY()) * doc->getGridY() - sp.y() );
- snaptqStatus = KoGuides::SNAP_BOTH;
+ snapStatus = KoGuides::SNAP_BOTH;
}
if ( snapToGuideLines )
{
- m_gl.snapToGuideLines( sp, MOUSE_SNAP_DISTANCE, snaptqStatus, snapDiff );
+ m_gl.snapToGuideLines( sp, MOUSE_SNAP_DISTANCE, snapStatus, snapDiff );
}
sp += snapDiff;
diff --git a/kpresenter/KPrDocument.cpp b/kpresenter/KPrDocument.cpp
index 7a880406..d7cb13cf 100644
--- a/kpresenter/KPrDocument.cpp
+++ b/kpresenter/KPrDocument.cpp
@@ -490,7 +490,7 @@ TQDomDocument KPrDocument::saveXML()
emit sigProgress( 0 );
}
- m_varColl->variableSetting()->setModificationDate(TQDateTime::tqcurrentDateTime());
+ m_varColl->variableSetting()->setModificationDate(TQDateTime::currentDateTime());
recalcVariables( VT_DATE );
recalcVariables( VT_TIME );
recalcVariables( VT_STATISTIC );
@@ -1006,7 +1006,7 @@ bool KPrDocument::saveOasis( KoStore* store, KoXmlWriter* manifestWriter )
KoXmlWriter* contentWriter = createOasisXmlWriter( &contentDev, "office:document-content" );
- m_varColl->variableSetting()->setModificationDate(TQDateTime::tqcurrentDateTime());
+ m_varColl->variableSetting()->setModificationDate(TQDateTime::currentDateTime());
recalcVariables( VT_DATE );
recalcVariables( VT_TIME );
recalcVariables( VT_STATISTIC );
@@ -3386,7 +3386,7 @@ void KPrDocument::setEmpty()
{
KoDocument::setEmpty();
// Whether loaded from template or from empty doc: this is a new one -> set creation date
- m_varColl->variableSetting()->setCreationDate(TQDateTime::tqcurrentDateTime());
+ m_varColl->variableSetting()->setCreationDate(TQDateTime::currentDateTime());
recalcVariables( VT_DATE ); // , VST_CREATION_DATE ...
// If we then load a document, it will override that date.
}
diff --git a/kpresenter/KPrEffectDia.cpp b/kpresenter/KPrEffectDia.cpp
index a394e0a8..abddeb68 100644
--- a/kpresenter/KPrEffectDia.cpp
+++ b/kpresenter/KPrEffectDia.cpp
@@ -68,7 +68,7 @@ KPrEffectDia::KPrEffectDia( TQWidget* parent, const char* name, const TQPtrList<
TQGridLayout *upperRow = new TQGridLayout(grp1->tqlayout(), 6, 4);
lAppear = new TQLabel( i18n( "Order of appearance:" ), grp1 );
- lAppear->tqsetAlignment( AlignVCenter );
+ lAppear->setAlignment( AlignVCenter );
upperRow->addWidget(lAppear, 0, 0);
eAppearStep = new TQSpinBox( 0, 100, 1, grp1 );
@@ -79,7 +79,7 @@ KPrEffectDia::KPrEffectDia( TQWidget* parent, const char* name, const TQPtrList<
//( void )new TQWidget( grp1 );
lEffect = new TQLabel( i18n( "Effect (appearing):" ), grp1 );
- lEffect->tqsetAlignment( AlignVCenter );
+ lEffect->setAlignment( AlignVCenter );
upperRow->addWidget(lEffect, 1, 0);
cEffect = new TQComboBox( false, grp1, "cEffect" );
@@ -102,7 +102,7 @@ KPrEffectDia::KPrEffectDia( TQWidget* parent, const char* name, const TQPtrList<
connect( cEffect, TQT_SIGNAL( activated( int ) ), this, TQT_SLOT( appearEffectChanged( int ) ) );
lAppearSpeed = new TQLabel( i18n( "Speed:" ), grp1 );
- lAppearSpeed->tqsetAlignment( AlignVCenter );
+ lAppearSpeed->setAlignment( AlignVCenter );
upperRow->addWidget(lAppearSpeed, 2, 0);
cAppearSpeed = new TQComboBox( false, grp1, "cEffect" );
@@ -114,7 +114,7 @@ KPrEffectDia::KPrEffectDia( TQWidget* parent, const char* name, const TQPtrList<
appearEffectChanged( cEffect->currentItem() );
lEffect2 = new TQLabel( i18n( "Effect (object specific):" ), grp1 );
- lEffect2->tqsetAlignment( AlignVCenter );
+ lEffect2->setAlignment( AlignVCenter );
upperRow->addWidget(lEffect2, 3, 0);
cEffect2 = new TQComboBox( false, grp1, "cEffect2" );
@@ -144,7 +144,7 @@ KPrEffectDia::KPrEffectDia( TQWidget* parent, const char* name, const TQPtrList<
}
TQLabel *lTimerOfAppear = new TQLabel( i18n( "Timer of the object:" ), grp1 );
- lTimerOfAppear->tqsetAlignment( AlignVCenter );
+ lTimerOfAppear->setAlignment( AlignVCenter );
upperRow->addWidget( lTimerOfAppear, 4, 0 );
timerOfAppear = new KIntNumInput( obj->getAppearTimer(), grp1 );
@@ -164,7 +164,7 @@ KPrEffectDia::KPrEffectDia( TQWidget* parent, const char* name, const TQPtrList<
connect( appearSoundEffect, TQT_SIGNAL( clicked() ), this, TQT_SLOT( appearSoundEffectChanged() ) );
lSoundEffect1 = new TQLabel( i18n( "File name:" ), grp1 );
- lSoundEffect1->tqsetAlignment( AlignVCenter );
+ lSoundEffect1->setAlignment( AlignVCenter );
upperRow->addWidget( lSoundEffect1, 6, 0 );
requester1 = new KURLRequester( grp1 );
@@ -203,7 +203,7 @@ KPrEffectDia::KPrEffectDia( TQWidget* parent, const char* name, const TQPtrList<
TQGridLayout *lowerRow = new TQGridLayout(grp2->tqlayout(), 5, 4);
lDisappear = new TQLabel( i18n( "Order of disappearance:" ), grp2 );
- lDisappear->tqsetAlignment( AlignVCenter );
+ lDisappear->setAlignment( AlignVCenter );
lowerRow->addWidget(lDisappear, 0, 0);
eDisappearStep = new TQSpinBox( 0, 100, 1, grp2 );
@@ -211,7 +211,7 @@ KPrEffectDia::KPrEffectDia( TQWidget* parent, const char* name, const TQPtrList<
lowerRow->addWidget(eDisappearStep, 0, 1);
lDEffect = new TQLabel( i18n( "Effect (disappearing):" ), grp2 );
- lDEffect->tqsetAlignment( AlignVCenter );
+ lDEffect->setAlignment( AlignVCenter );
lowerRow->addWidget(lDEffect, 1, 0);
cDisappear = new TQComboBox( false, grp2, "cDisappear" );
@@ -234,7 +234,7 @@ KPrEffectDia::KPrEffectDia( TQWidget* parent, const char* name, const TQPtrList<
connect( cDisappear, TQT_SIGNAL( activated( int ) ), this, TQT_SLOT( disappearEffectChanged( int ) ) );
lDisappearSpeed = new TQLabel( i18n( "Speed:" ), grp2 );
- lDisappearSpeed->tqsetAlignment( AlignVCenter );
+ lDisappearSpeed->setAlignment( AlignVCenter );
lowerRow->addWidget(lDisappearSpeed, 2, 0);
cDisappearSpeed = new TQComboBox( false, grp2, "cEffect" );
@@ -247,7 +247,7 @@ KPrEffectDia::KPrEffectDia( TQWidget* parent, const char* name, const TQPtrList<
//appearEffectChanged( cEffect->currentItem() );
TQLabel *lTimerOfDisappear = new TQLabel( i18n( "Timer of the object:" ), grp2 );
- lTimerOfDisappear->tqsetAlignment( AlignVCenter );
+ lTimerOfDisappear->setAlignment( AlignVCenter );
lowerRow->addWidget( lTimerOfDisappear, 3, 0 );
timerOfDisappear = new KIntNumInput( obj->getDisappearTimer(), grp2 );
@@ -268,7 +268,7 @@ KPrEffectDia::KPrEffectDia( TQWidget* parent, const char* name, const TQPtrList<
connect( disappearSoundEffect, TQT_SIGNAL( clicked() ), this, TQT_SLOT( disappearSoundEffectChanged() ) );
lSoundEffect2 = new TQLabel( i18n( "File name:" ), grp2 );
- lSoundEffect2->tqsetAlignment( AlignVCenter );
+ lSoundEffect2->setAlignment( AlignVCenter );
lowerRow->addWidget( lSoundEffect2, 5, 0 );
requester2 = new KURLRequester( grp2 );
diff --git a/kpresenter/KPrMSPresentationSetup.cpp b/kpresenter/KPrMSPresentationSetup.cpp
index f9a87fd5..298e8645 100644
--- a/kpresenter/KPrMSPresentationSetup.cpp
+++ b/kpresenter/KPrMSPresentationSetup.cpp
@@ -298,13 +298,13 @@ KPrMSPresentationSetup::KPrMSPresentationSetup( KPrDocument *_doc, KPrView *_vie
TQLabel *helptext = new TQLabel( this );
- helptext->tqsetAlignment( TQt::WordBreak | TQt::AlignTop| TQt::AlignLeft );
+ helptext->setAlignment( TQt::WordBreak | TQt::AlignTop| TQt::AlignLeft );
helptext->setText( i18n( "Please enter the directory where the memory stick "
"presentation should be saved. Please also enter a "
"title for the slideshow presentation. " ) );
TQLabel *lable2 = new TQLabel( i18n("Path:"), this );
- lable2->tqsetAlignment( TQt::AlignVCenter | TQt::AlignRight );
+ lable2->setAlignment( TQt::AlignVCenter | TQt::AlignRight );
path=new KURLRequester( this );
path->setMode( KFile::Directory);
path->lineEdit()->setText(msPres.getPath());
@@ -320,7 +320,7 @@ KPrMSPresentationSetup::KPrMSPresentationSetup( KPrDocument *_doc, KPrView *_vie
TQLabel *lable1 = new TQLabel( i18n("Title:"), this, "lable1" );
- lable1->tqsetAlignment( TQt::AlignVCenter | TQt::AlignRight );
+ lable1->setAlignment( TQt::AlignVCenter | TQt::AlignRight );
// TODO - check if there is already a presentation with this title, and
// add a number after it until there isn't.
title = new KLineEdit( msPres.getTitle(), this );
@@ -351,13 +351,13 @@ KPrMSPresentationSetup::KPrMSPresentationSetup( KPrDocument *_doc, KPrView *_vie
"leave these set to the default.") );
TQHBox *textColourLayout = new TQHBox( colourGroup );
TQLabel *lable3 = new TQLabel( i18n("Text color:"), textColourLayout );
- lable3->tqsetAlignment( TQt::AlignVCenter | TQt::AlignRight );
+ lable3->setAlignment( TQt::AlignVCenter | TQt::AlignRight );
textColour = new KColorButton( msPres.getTextColour(), textColourLayout );
lable3->setBuddy( textColour );
TQHBox *backgroundColourLayout = new TQHBox( colourGroup );
TQLabel *lable4 = new TQLabel( i18n("Background color:"), backgroundColourLayout );
- lable4->tqsetAlignment( TQt::AlignVCenter | TQt::AlignRight );
+ lable4->setAlignment( TQt::AlignVCenter | TQt::AlignRight );
backColour = new KColorButton( msPres.getBackColour(), backgroundColourLayout );
lable4->setBuddy( backColour );
colourGroup->setHidden( true );
diff --git a/kpresenter/KPrNoteBar.cpp b/kpresenter/KPrNoteBar.cpp
index 10048537..576b11cc 100644
--- a/kpresenter/KPrNoteBar.cpp
+++ b/kpresenter/KPrNoteBar.cpp
@@ -145,7 +145,7 @@ void KPrNoteBar::printNotes( TQPainter *_painter, KPrinter *_printer, TQValueLis
TQRect viewRect( body );
do {
- richText.draw( _painter, body.left(), body.top(), viewRect, tqcolorGroup() );
+ richText.draw( _painter, body.left(), body.top(), viewRect, colorGroup() );
viewRect.moveBy( 0, body.height() );
_painter->translate( 0, -body.height() );
_painter->setFont( font );
diff --git a/kpresenter/KPrPBPreview.cpp b/kpresenter/KPrPBPreview.cpp
index 1afef977..d1afdd8b 100644
--- a/kpresenter/KPrPBPreview.cpp
+++ b/kpresenter/KPrPBPreview.cpp
@@ -67,7 +67,7 @@ void KPrPBPreview::drawContents( TQPainter *painter )
if ( paintType == Pen ) {
painter->fillRect( 0, 0, contentsRect().width(), contentsRect().height(),
- tqcolorGroup().base() );
+ colorGroup().base() );
KoSize diff1( 0, 0 ), diff2( 0, 0 );
int _w = int( pen.pointWidth() );
@@ -94,7 +94,7 @@ void KPrPBPreview::drawContents( TQPainter *painter )
} else if ( paintType == Brush ) {
painter->fillRect( 0, 0, contentsRect().width(), contentsRect().height(),
- tqcolorGroup().base() );
+ colorGroup().base() );
painter->fillRect( 0, 0, contentsRect().width(), contentsRect().height(), brush );
} else if ( paintType == Gradient )
painter->drawPixmap( 0, 0, gradient->pixmap());
diff --git a/kpresenter/KPrPgConfDia.cpp b/kpresenter/KPrPgConfDia.cpp
index a7df156f..0b1aab1f 100644
--- a/kpresenter/KPrPgConfDia.cpp
+++ b/kpresenter/KPrPgConfDia.cpp
@@ -209,7 +209,7 @@ void KPrPgConfDia::setupPageSlides()
TQWidget* spacer = new TQWidget( buttonGroup );
- spacer->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Expanding ) );
+ spacer->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Expanding ) );
slidesLayout->addMultiCellWidget( buttonGroup, 4, 4, 0, 1 );
if ( !m_doc->presentationName().isEmpty() )
diff --git a/kpresenter/KPrPixmapObject.cpp b/kpresenter/KPrPixmapObject.cpp
index 0a4c8921..9e4320e3 100644
--- a/kpresenter/KPrPixmapObject.cpp
+++ b/kpresenter/KPrPixmapObject.cpp
@@ -365,7 +365,7 @@ void KPrPixmapObject::loadOasis(const TQDomElement &element, KoOasisContext & co
strExtension=href.mid(result+1); // As we are using KoPicture, the extension should be without the dot.
}
TQString filename(href/*.mid(1)*/);
- const KoPictureKey key(filename, TQDateTime::tqcurrentDateTime(Qt::UTC));
+ const KoPictureKey key(filename, TQDateTime::currentDateTime(Qt::UTC));
image.setKey(key);
KoStore* store = context.store();
diff --git a/kpresenter/KPrPresDurationDia.cpp b/kpresenter/KPrPresDurationDia.cpp
index 88163c62..34f578f6 100644
--- a/kpresenter/KPrPresDurationDia.cpp
+++ b/kpresenter/KPrPresDurationDia.cpp
@@ -48,7 +48,7 @@ KPrPresDurationDia::KPrPresDurationDia( TQWidget *parent, const char *name,
slides->setSelected( slides->firstChild(), true );
label = new TQLabel( i18n( "Presentation duration: " ) + _durationString, page );
- label->tqsetAlignment( AlignVCenter );
+ label->setAlignment( AlignVCenter );
topLayout->addWidget( label );
setMinimumSize( 600, 400 );
diff --git a/kpresenter/KPrSideBar.cpp b/kpresenter/KPrSideBar.cpp
index b39ab5b0..4988a5bb 100644
--- a/kpresenter/KPrSideBar.cpp
+++ b/kpresenter/KPrSideBar.cpp
@@ -762,7 +762,7 @@ KPrOutline::KPrOutline( TQWidget *parent, KPrDocument *d, KPrView *v )
setSorting( -1 );
header()->hide();
addColumn( i18n( "Slide" ) );
- tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Expanding ) );
+ setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Expanding ) );
connect( this, TQT_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQT_SLOT( itemClicked( TQListViewItem * ) ) );
connect( this, TQT_SIGNAL( rightButtonPressed( TQListViewItem *, const TQPoint &, int ) ),
diff --git a/kpresenter/KPrSideBar.h b/kpresenter/KPrSideBar.h
index b6450f11..8f23225f 100644
--- a/kpresenter/KPrSideBar.h
+++ b/kpresenter/KPrSideBar.h
@@ -109,7 +109,7 @@ public:
KPrOutline( TQWidget *parent, KPrDocument *d, KPrView *v );
~KPrOutline();
void setCurrentPage( int pg );
- TQSize tqsizeHint() const { return TQSize( 145, KListView::tqsizeHint().height() ); }
+ TQSize sizeHint() const { return TQSize( 145, KListView::sizeHint().height() ); }
void updateItem( int pagenr, bool sticky = false);
void addItem( int pos );
void moveItem( int oldPos, int newPos );
@@ -154,7 +154,7 @@ public:
m_thb->setCurrentPage(pg);
};
void setOn( int , bool ) { };
- //TQSize tqsizeHint() const { return TQSize( 120, TQTabWidget::tqsizeHint().height() ); };
+ //TQSize sizeHint() const { return TQSize( 120, TQTabWidget::sizeHint().height() ); };
void updateItem( KPrPage *page );
void addItem( int pos );
void moveItem( int oldPos, int newPos );
diff --git a/kpresenter/KPrTextProperty.cpp b/kpresenter/KPrTextProperty.cpp
index 6708065b..891ff5b4 100644
--- a/kpresenter/KPrTextProperty.cpp
+++ b/kpresenter/KPrTextProperty.cpp
@@ -45,7 +45,7 @@ KPrTextProperty::KPrTextProperty( TQWidget *parent, const char *name, const Marg
connect( m_protectContentCheck, TQT_SIGNAL( toggled ( bool ) ),
this, TQT_SLOT( slotProtectContentChanged( bool ) ) );
- resize( TQSize( 301, 217 ).expandedTo( tqminimumSizeHint() ) );
+ resize( TQSize( 301, 217 ).expandedTo( minimumSizeHint() ) );
m_margins->setValues( marginsStruct.leftMargin, marginsStruct.rightMargin,
marginsStruct.topMargin, marginsStruct.bottomMargin );
diff --git a/kpresenter/KPrTransEffectDia.cpp b/kpresenter/KPrTransEffectDia.cpp
index a7fc0899..3fad79a2 100644
--- a/kpresenter/KPrTransEffectDia.cpp
+++ b/kpresenter/KPrTransEffectDia.cpp
@@ -260,7 +260,7 @@ KPrTransEffectDia::KPrTransEffectDia( TQWidget *parent, const char *name,
automaticPreview->setChecked( true );
TQWidget* previewspacer = new TQWidget( previewgrp );
- previewspacer->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding,
+ previewspacer->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding,
TQSizePolicy::Expanding ) );
previewButton = new TQPushButton( previewgrp );
@@ -314,7 +314,7 @@ KPrTransEffectDia::KPrTransEffectDia( TQWidget *parent, const char *name,
connect( timeSlider, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(timeChanged(int)) );
TQWidget* rspacer = new TQWidget( rightpart );
- rspacer->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Expanding ) );
+ rspacer->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Expanding ) );
TQWidget* lspacer = new TQWidget( leftpart );
lspacer->setMinimumSize( 10, spacingHint() );
diff --git a/kpresenter/KPrView.cpp b/kpresenter/KPrView.cpp
index a86caa80..13e912f1 100644
--- a/kpresenter/KPrView.cpp
+++ b/kpresenter/KPrView.cpp
@@ -410,23 +410,23 @@ KPrView::KPrView( KPrDocument* _doc, TQWidget *_parent, const char *_name )
if ( sb ) // No statusbar in e.g. konqueror
{
m_sbPageLabel = new KStatusBarLabel( TQString(), 0, sb );
- m_sbPageLabel->tqsetAlignment( AlignLeft | AlignVCenter );
+ m_sbPageLabel->setAlignment( AlignLeft | AlignVCenter );
addStatusBarItem( m_sbPageLabel, 0 );
m_sbModifiedLabel = new KStatusBarLabel( " ", 0, sb );
- m_sbModifiedLabel->tqsetAlignment( AlignLeft | AlignVCenter );
+ m_sbModifiedLabel->setAlignment( AlignLeft | AlignVCenter );
addStatusBarItem( m_sbModifiedLabel, 0 );
m_sbObjectLabel = new KStatusBarLabel( TQString(), 0, sb );
- m_sbObjectLabel->tqsetAlignment( AlignLeft | AlignVCenter );
+ m_sbObjectLabel->setAlignment( AlignLeft | AlignVCenter );
addStatusBarItem( m_sbObjectLabel, 1 );
m_sbZoomLabel = new KStatusBarLabel( ' ' + TQString::number( m_pKPresenterDoc->zoomHandler()->zoom() ) + "% ", 0, sb );
- m_sbZoomLabel->tqsetAlignment( AlignHCenter | AlignVCenter );
+ m_sbZoomLabel->setAlignment( AlignHCenter | AlignVCenter );
addStatusBarItem( m_sbZoomLabel, 0 );
m_sbUnitLabel = new KStatusBarLabel( ' ' + KoUnit::unitDescription( m_pKPresenterDoc->unit() ) + ' ', 0, sb );
- m_sbUnitLabel->tqsetAlignment( AlignHCenter | AlignVCenter );
+ m_sbUnitLabel->setAlignment( AlignHCenter | AlignVCenter );
addStatusBarItem( m_sbUnitLabel, 0 );
}
@@ -581,7 +581,7 @@ void KPrView::print( KPrinter &prt )
m_canvas->tqrepaint();
kdDebug(33001) << "KPrView::print zoom&res reset" << endl;
- m_pKPresenterDoc->getVariableCollection()->variableSetting()->setLastPrintingDate(TQDateTime::tqcurrentDateTime());
+ m_pKPresenterDoc->getVariableCollection()->variableSetting()->setLastPrintingDate(TQDateTime::currentDateTime());
m_pKPresenterDoc->recalcVariables( VT_DATE );
}
@@ -632,7 +632,7 @@ void KPrView::editPaste()
{
// TODO: it would be nice to have no offset when pasting onto a different page...
m_canvas->activePage()->pasteObjs(
- data->tqencodedData(KoStoreDrag::mimeType("application/x-kpresenter")),
+ data->encodedData(KoStoreDrag::mimeType("application/x-kpresenter")),
1, 0.0, 0.0, 0.0, 20.0, 20.0);
m_canvas->setMouseSelectedObject(true);
@@ -644,7 +644,7 @@ void KPrView::editPaste()
//TODO : fix me !!
// TODO: it would be nice to have no offset when pasting onto a different page...
//m_canvas->activePage()->pasteObjs(
- //data->tqencodedData(KoStoreDrag::mimeType("application/vnd.oasis.opendocument.presentation")),
+ //data->encodedData(KoStoreDrag::mimeType("application/vnd.oasis.opendocument.presentation")),
//1, 0.0, 0.0, 0.0, 20.0, 20.0);
m_canvas->setMouseSelectedObject(true);
@@ -1274,7 +1274,7 @@ void KPrView::extraShadow()
if ( !shadowDia ) {
shadowDia = new KPrShadowDialogImpl( this );
- shadowDia->resize( shadowDia->tqminimumSize() );
+ shadowDia->resize( shadowDia->minimumSize() );
connect( shadowDia, TQT_SIGNAL( apply() ), TQT_TQOBJECT(this), TQT_SLOT( shadowOk() ) );
}
@@ -1509,7 +1509,7 @@ void KPrView::startScreenPres( int pgNum /*1-based*/ )
KProcess proc;
proc << xdgScreenSaver;
proc << "suspend";
- proc << TQString::number( tqtopLevelWidget()->winId() );
+ proc << TQString::number( topLevelWidget()->winId() );
kdDebug() << k_funcinfo << proc.args() << endl;
proc.start( KProcess::DontCare );
} else {
@@ -1633,7 +1633,7 @@ void KPrView::screenStop()
KProcess proc;
proc << xdgScreenSaver;
proc << "resume";
- proc << TQString::number( tqtopLevelWidget()->winId() );
+ proc << TQString::number( topLevelWidget()->winId() );
kdDebug() << k_funcinfo << proc.args() << endl;
proc.start( KProcess::DontCare );
} else {
@@ -1856,7 +1856,7 @@ void KPrView::slotApplyFont()
void KPrView::slotCounterStyleSelected()
{
- TQString actionName = TQString::tqfromLatin1(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name());
+ TQString actionName = TQString::fromLatin1(TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name());
if ( actionName.startsWith( "counterstyle_" ) )
{
TQString styleStr = actionName.mid(13);
@@ -2175,7 +2175,7 @@ void KPrView::createGUI()
// setup page
pageBase = new PageBase( splitterVertical, this );
- pageBase->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
+ pageBase->setSizePolicy( TQSizePolicy( TQSizePolicy::Expanding, TQSizePolicy::Expanding ) );
m_canvas=new KPrCanvas( pageBase, "Canvas", this );
@@ -3491,8 +3491,8 @@ void KPrView::reorganize()
if(kPresenterDoc()->showRuler())
{
- int hSpace = v_ruler->tqminimumSizeHint().width();
- int vSpace = h_ruler->tqminimumSizeHint().height();
+ int hSpace = v_ruler->minimumSizeHint().width();
+ int vSpace = h_ruler->minimumSizeHint().height();
m_canvas->move( hSpace, vSpace );
if ( h_ruler )
@@ -3552,8 +3552,8 @@ void PageBase::resizeEvent( TQResizeEvent *e )
TQSize s = e ? e->size() : size();
if ( view->m_bShowGUI ) {
- int hSpace = view->getVRuler()->tqminimumSizeHint().width();
- int vSpace = view->getVRuler()->tqminimumSizeHint().height();
+ int hSpace = view->getVRuler()->minimumSizeHint().width();
+ int vSpace = view->getVRuler()->minimumSizeHint().height();
view->m_canvas->resize( s.width() - ( hSpace + 16 ), s.height() - ( vSpace + 16 ) );
view->vert->setGeometry( s.width() - 16, 0, 16, s.height() - 32 );
@@ -3778,8 +3778,8 @@ void KPrView::setupRulers()
v_ruler = new KoRuler( pageBase, m_canvas, Qt::Vertical, kPresenterDoc()->pageLayout(), 0, kPresenterDoc()->unit() );
v_ruler->setReadWrite(kPresenterDoc()->isReadWrite());
- int hSpace = v_ruler->tqminimumSizeHint().width();
- int vSpace = h_ruler->tqminimumSizeHint().height();
+ int hSpace = v_ruler->minimumSizeHint().width();
+ int vSpace = h_ruler->minimumSizeHint().height();
m_canvas->resize( m_canvas->width() - hSpace, m_canvas->height() - vSpace );
m_canvas->move( hSpace, vSpace );
@@ -5968,7 +5968,7 @@ void KPrView::duplicateObj()
TQCString clip_str = KoStoreDrag::mimeType("application/x-kpresenter");
if ( data->provides( clip_str ) )
{
- m_canvas->activePage()->pasteObjs( data->tqencodedData(clip_str),
+ m_canvas->activePage()->pasteObjs( data->encodedData(clip_str),
nbCopy, angle, increaseX,increaseY, moveX, moveY );
m_canvas->setMouseSelectedObject(true);
emit objectSelectedChanged();
diff --git a/kpresenter/KPrWebPresentation.cpp b/kpresenter/KPrWebPresentation.cpp
index 2197cf32..40ad82be 100644
--- a/kpresenter/KPrWebPresentation.cpp
+++ b/kpresenter/KPrWebPresentation.cpp
@@ -211,7 +211,7 @@ void KPrWebPresentation::loadConfig()
if ( num <= slideInfos.count() ) {
for ( unsigned int i = 0; i < num; i++ )
{
- TQString key = TQString::tqfromLatin1( "SlideTitle%1" ).tqarg( i );
+ TQString key = TQString::fromLatin1( "SlideTitle%1" ).tqarg( i );
if ( cfg.hasKey( key ) )
{
// We'll assume that the selected pages haven't changed... Hmm.
@@ -245,7 +245,7 @@ void KPrWebPresentation::saveConfig()
cfg.writeEntry( "Slides", slideInfos.count() );
for ( unsigned int i = 0; i < slideInfos.count(); i++ )
- cfg.writeEntry( TQString::tqfromLatin1( "SlideTitle%1" ).tqarg( i ), slideInfos[ i ].slideTitle );
+ cfg.writeEntry( TQString::fromLatin1( "SlideTitle%1" ).tqarg( i ), slideInfos[ i ].slideTitle );
cfg.writeEntry( "BackColor", backColor );
cfg.writeEntry( "TitleColor", titleColor );
@@ -511,7 +511,7 @@ void KPrWebPresentation::createSlidesHTML( KProgress *progressBar )
else
htmlAuthor=TQString("<a href=\"mailto:%1\">%2</a>").tqarg( escapeHtmlText( codec, email )).tqarg( escapeHtmlText( codec, author ));
streamOut << EscapeEncodingOnly ( codec, i18n( "Created on %1 by <i>%2</i> with <a href=\"http://www.koffice.org/kpresenter\">KPresenter</a>" )
- .tqarg( KGlobal::locale()->formatDate ( TQDate::tqcurrentDate() ) ).tqarg( htmlAuthor ) );
+ .tqarg( KGlobal::locale()->formatDate ( TQDate::currentDate() ) ).tqarg( htmlAuthor ) );
streamOut << " </center><hr noshade=\"noshade\"" << ( isXML() ?" /":"") << ">\n";
}
@@ -562,7 +562,7 @@ void KPrWebPresentation::createMainPage( KProgress *progressBar )
TQString htmlAuthor = email.isEmpty() ? escapeHtmlText( codec, author ) :
TQString("<a href=\"mailto:%1\">%2</a>").tqarg( escapeHtmlText( codec, email )).tqarg( escapeHtmlText( codec, author ));
streamOut << EscapeEncodingOnly ( codec, i18n( "Created on %1 by <i>%2</i> with <a href=\"http://www.koffice.org/kpresenter\">KPresenter</a>" )
- .tqarg( KGlobal::locale()->formatDate ( TQDate::tqcurrentDate() ) ).tqarg( htmlAuthor ) );
+ .tqarg( KGlobal::locale()->formatDate ( TQDate::currentDate() ) ).tqarg( htmlAuthor ) );
streamOut << "</body>\n</html>\n";
file.close();
@@ -668,7 +668,7 @@ void KPrWebPresentationWizard::setupPage1()
KDialog::marginHint(), KDialog::spacingHint() );
TQLabel *helptext = new TQLabel( canvas );
- helptext->tqsetAlignment( TQt::WordBreak | TQt::AlignTop| TQt::AlignLeft );
+ helptext->setAlignment( TQt::WordBreak | TQt::AlignTop| TQt::AlignLeft );
helptext->setText( i18n( "Enter your name, email address and "
"the title of the web presentation. "
"Also enter the output directory where the "
@@ -678,27 +678,27 @@ void KPrWebPresentationWizard::setupPage1()
tqlayout->addMultiCell( new TQSpacerItem( 1, 50 ), 1, 1, 0, 1 );
TQLabel *label1 = new TQLabel( i18n("Author:"), canvas );
- label1->tqsetAlignment( TQt::AlignVCenter | TQt::AlignRight );
+ label1->setAlignment( TQt::AlignVCenter | TQt::AlignRight );
TQWhatsThis::add( label1, i18n("This is where you enter the name of the person or "
"organization that should be named as the author of "
"the presentation.") );
tqlayout->addWidget( label1, 2, 0 );
TQLabel *label2 = new TQLabel( i18n("Title:"), canvas );
- label2->tqsetAlignment( TQt::AlignVCenter | TQt::AlignRight );
+ label2->setAlignment( TQt::AlignVCenter | TQt::AlignRight );
TQWhatsThis::add( label2, i18n("This is where you enter the title of the overall "
"presentation." ) );
tqlayout->addWidget( label2, 3, 0 );
TQLabel *label3 = new TQLabel( i18n("Email address:"), canvas );
- label3->tqsetAlignment( TQt::AlignVCenter | TQt::AlignRight );
+ label3->setAlignment( TQt::AlignVCenter | TQt::AlignRight );
TQWhatsThis::add( label3, i18n("This is where you enter the email address of the "
"person or organization that is responsible for "
"the presentation.") );
tqlayout->addWidget( label3, 4, 0 );
TQLabel *label4 = new TQLabel( i18n("Path:"), canvas );
- label4->tqsetAlignment( TQt::AlignVCenter | TQt::AlignRight );
+ label4->setAlignment( TQt::AlignVCenter | TQt::AlignRight );
TQWhatsThis::add( label4, i18n("The value entered for the path is the directory "
"where the presentation will be saved. If it does "
"not exist, you'll be asked if you want to create "
@@ -766,7 +766,7 @@ void KPrWebPresentationWizard::setupPage2()
KDialog::marginHint(), KDialog::spacingHint() );
TQLabel *helptext = new TQLabel( canvas );
- helptext->tqsetAlignment( TQt::WordBreak | TQt::AlignVCenter| TQt::AlignLeft );
+ helptext->setAlignment( TQt::WordBreak | TQt::AlignVCenter| TQt::AlignLeft );
TQString help = i18n("Here you can configure the style of the web pages.");
help += i18n( "You can also specify the zoom for the slides." );
helptext->setText(help);
@@ -776,18 +776,18 @@ void KPrWebPresentationWizard::setupPage2()
tqlayout->addMultiCell( new TQSpacerItem( 1, 50 ), 1, 1, 0, 1 );
TQLabel *label1 = new TQLabel( i18n("Zoom:"), canvas );
- label1->tqsetAlignment( TQt::AlignVCenter | TQt::AlignRight );
+ label1->setAlignment( TQt::AlignVCenter | TQt::AlignRight );
TQWhatsThis::add( label1, i18n( "This selection allows you to specify "
"the size of the slide image." ) );
tqlayout->addWidget( label1, 2, 0 );
TQLabel *label2 = new TQLabel( i18n( "Encoding:" ), canvas );
- label2->tqsetAlignment( TQt::AlignVCenter | TQt::AlignRight );
+ label2->setAlignment( TQt::AlignVCenter | TQt::AlignRight );
tqlayout->addWidget( label2, 3, 0 );
TQLabel *label3 = new TQLabel( i18n( "Document type:" ), canvas );
- label3->tqsetAlignment( TQt::AlignVCenter | TQt::AlignRight );
+ label3->setAlignment( TQt::AlignVCenter | TQt::AlignRight );
tqlayout->addWidget( label3, 4, 0 );
zoom = new KIntNumInput( webPres.getZoom(), canvas );
@@ -856,22 +856,22 @@ void KPrWebPresentationWizard::setupPage3()
KDialog::marginHint(), KDialog::spacingHint() );
TQLabel *helptext = new TQLabel( canvas );
- helptext->tqsetAlignment( TQt::WordBreak | TQt::AlignVCenter| TQt::AlignLeft );
+ helptext->setAlignment( TQt::WordBreak | TQt::AlignVCenter| TQt::AlignLeft );
helptext->setText( i18n( "Now you can customize the colors of the web pages." ) );
tqlayout->addMultiCellWidget( helptext, 0, 0, 0, 1 );
tqlayout->addMultiCell( new TQSpacerItem( 1, 50 ), 1, 1, 0, 1 );
TQLabel *label1 = new TQLabel( i18n("Text color:"), canvas );
- label1->tqsetAlignment( TQt::AlignVCenter | TQt::AlignRight );
+ label1->setAlignment( TQt::AlignVCenter | TQt::AlignRight );
tqlayout->addWidget( label1, 2, 0 );
TQLabel *label2 = new TQLabel( i18n("Title color:"), canvas );
- label2->tqsetAlignment( TQt::AlignVCenter | TQt::AlignRight );
+ label2->setAlignment( TQt::AlignVCenter | TQt::AlignRight );
tqlayout->addWidget( label2, 3, 0 );
TQLabel *label3 = new TQLabel( i18n("Background color:"), canvas );
- label3->tqsetAlignment( TQt::AlignVCenter | TQt::AlignRight );
+ label3->setAlignment( TQt::AlignVCenter | TQt::AlignRight );
tqlayout->addWidget( label3, 4, 0 );
textColor = new KColorButton( webPres.getTextColor(), canvas );
@@ -913,7 +913,7 @@ void KPrWebPresentationWizard::setupPage4()
KDialog::marginHint(), KDialog::spacingHint() );
TQLabel *helptext = new TQLabel( canvas );
- helptext->tqsetAlignment( TQt::WordBreak | TQt::AlignVCenter| TQt::AlignLeft );
+ helptext->setAlignment( TQt::WordBreak | TQt::AlignVCenter| TQt::AlignLeft );
helptext->setText( i18n( "Here you can specify titles for "
"each slide. Click on a slide in "
"the list and then enter the title "
@@ -924,7 +924,7 @@ void KPrWebPresentationWizard::setupPage4()
tqlayout->addMultiCellWidget( helptext, 0, 0, 0, 1 );
TQLabel *label = new TQLabel( i18n( "Slide title:" ), canvas );
- label->tqsetAlignment( TQt::AlignVCenter | TQt::AlignRight );
+ label->setAlignment( TQt::AlignVCenter | TQt::AlignRight );
tqlayout->addWidget( label, 1, 0 );
slideTitle = new KLineEdit( canvas );
@@ -981,7 +981,7 @@ void KPrWebPresentationWizard::setupPage5()
KDialog::marginHint(), KDialog::spacingHint() );
TQLabel *helptext = new TQLabel( canvas );
- helptext->tqsetAlignment( TQt::WordBreak | TQt::AlignVCenter| TQt::AlignLeft );
+ helptext->setAlignment( TQt::WordBreak | TQt::AlignVCenter| TQt::AlignLeft );
TQString help = i18n("Here you can configure some options for unattended "
"presentations, such as time elapsed before automatically advance to "
"the next slide, looping and the presence of headers.");
@@ -992,7 +992,7 @@ void KPrWebPresentationWizard::setupPage5()
tqlayout->addMultiCell( new TQSpacerItem( 1, 50 ), 1, 1, 0, 1 );
TQLabel *label1 = new TQLabel( i18n("Advance after:"), canvas );
- label1->tqsetAlignment( TQt::AlignVCenter | TQt::AlignRight );
+ label1->setAlignment( TQt::AlignVCenter | TQt::AlignRight );
TQWhatsThis::add( label1, i18n( "This selection allows you to specify "
"the time between slides." ) );
tqlayout->addWidget( label1, 2, 0 );
diff --git a/kpresenter/autoformEdit/AFChoose.cpp b/kpresenter/autoformEdit/AFChoose.cpp
index ccbfc0e8..7043a692 100644
--- a/kpresenter/autoformEdit/AFChoose.cpp
+++ b/kpresenter/autoformEdit/AFChoose.cpp
@@ -137,7 +137,7 @@ void AFChoose::setupTabs()
continue; // Invalid .desktop file
}
}
- grpPtr->loadWid->setBackgroundColor(tqcolorGroup().base());
+ grpPtr->loadWid->setBackgroundColor(colorGroup().base());
grpPtr->loadWid->setResizeMode(TQIconView::Adjust);
grpPtr->loadWid->sort();
connect(grpPtr->loadWid,TQT_SIGNAL(nameChanged(TQString)),
@@ -148,7 +148,7 @@ void AFChoose::setupTabs()
TQT_SLOT(slotDoubleClick()));
grpPtr->label = new TQLabel(grpPtr->tab);
grpPtr->label->setText(" ");
- grpPtr->label->setMaximumHeight(grpPtr->label->tqsizeHint().height());
+ grpPtr->label->setMaximumHeight(grpPtr->label->sizeHint().height());
addTab(grpPtr->tab,grpPtr->name);
}
}
diff --git a/kpresenter/generalpropertyui.ui b/kpresenter/generalpropertyui.ui
index eec430f1..1161f42b 100644
--- a/kpresenter/generalpropertyui.ui
+++ b/kpresenter/generalpropertyui.ui
@@ -157,7 +157,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>21</height>
diff --git a/kpresenter/imageEffectBase.ui b/kpresenter/imageEffectBase.ui
index 430bfac8..84d38866 100644
--- a/kpresenter/imageEffectBase.ui
+++ b/kpresenter/imageEffectBase.ui
@@ -48,7 +48,7 @@
<verstretch>1</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>300</width>
<height>200</height>
@@ -336,7 +336,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>130</height>
@@ -409,7 +409,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>130</height>
@@ -471,7 +471,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>81</height>
@@ -523,7 +523,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>71</height>
@@ -572,7 +572,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>111</height>
@@ -621,7 +621,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>71</height>
@@ -718,7 +718,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>111</height>
@@ -767,7 +767,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>121</height>
@@ -867,7 +867,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>101</height>
@@ -946,7 +946,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>101</height>
@@ -998,7 +998,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>101</height>
@@ -1050,7 +1050,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>181</height>
@@ -1102,7 +1102,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>181</height>
@@ -1148,7 +1148,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>71</height>
@@ -1200,7 +1200,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>181</height>
@@ -1246,7 +1246,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>183</height>
@@ -1325,7 +1325,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>41</height>
@@ -1374,7 +1374,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>81</height>
@@ -1436,7 +1436,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>91</height>
diff --git a/kpresenter/insertpagedia.ui b/kpresenter/insertpagedia.ui
index 9d7372cf..aecf704d 100644
--- a/kpresenter/insertpagedia.ui
+++ b/kpresenter/insertpagedia.ui
@@ -137,7 +137,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
diff --git a/kpresenter/penstyle.ui b/kpresenter/penstyle.ui
index bcbcca09..56241f6f 100644
--- a/kpresenter/penstyle.ui
+++ b/kpresenter/penstyle.ui
@@ -82,7 +82,7 @@
<property name="name">
<cstring>pbPreview</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>80</width>
<height>40</height>
diff --git a/kpresenter/picturepropertyui.ui b/kpresenter/picturepropertyui.ui
index 6812256c..b1df2a2f 100644
--- a/kpresenter/picturepropertyui.ui
+++ b/kpresenter/picturepropertyui.ui
@@ -131,7 +131,7 @@
<property name="name">
<cstring>picturePreview</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>200</width>
<height>200</height>
diff --git a/kpresenter/piepropertyui.ui b/kpresenter/piepropertyui.ui
index 854e3168..39c77f24 100644
--- a/kpresenter/piepropertyui.ui
+++ b/kpresenter/piepropertyui.ui
@@ -56,7 +56,7 @@
<property name="name">
<cstring>piePreview</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>200</width>
<height>200</height>
diff --git a/kpresenter/polygonpropertyui.ui b/kpresenter/polygonpropertyui.ui
index 2b1b87dd..dd0be8e6 100644
--- a/kpresenter/polygonpropertyui.ui
+++ b/kpresenter/polygonpropertyui.ui
@@ -42,7 +42,7 @@
<property name="name">
<cstring>polygonPreview</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>200</width>
<height>200</height>
diff --git a/kpresenter/rectpropertyui.ui b/kpresenter/rectpropertyui.ui
index ce16ef61..ff66c8b7 100644
--- a/kpresenter/rectpropertyui.ui
+++ b/kpresenter/rectpropertyui.ui
@@ -111,13 +111,13 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>16</width>
<height>0</height>
</size>
</property>
- <property name="tqmaximumSize">
+ <property name="maximumSize">
<size>
<width>16</width>
<height>32767</height>
@@ -142,7 +142,7 @@
<property name="name">
<cstring>rectPreview</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>200</width>
<height>100</height>
diff --git a/kpresenter/rotationpropertyui.ui b/kpresenter/rotationpropertyui.ui
index ea998478..f54609ae 100644
--- a/kpresenter/rotationpropertyui.ui
+++ b/kpresenter/rotationpropertyui.ui
@@ -100,7 +100,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>31</width>
<height>20</height>
@@ -113,7 +113,7 @@
<property name="name">
<cstring>previewPanel</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>160</width>
<height>160</height>
@@ -136,7 +136,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
diff --git a/kpresenter/shadowdialog.ui b/kpresenter/shadowdialog.ui
index 44fc0e02..9434c919 100644
--- a/kpresenter/shadowdialog.ui
+++ b/kpresenter/shadowdialog.ui
@@ -336,7 +336,7 @@
<property name="name">
<cstring>previewPanel</cstring>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>160</width>
<height>160</height>
@@ -389,7 +389,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>20</height>
diff --git a/kpresenter/slidetransitionwidget.ui b/kpresenter/slidetransitionwidget.ui
index 2314d8b9..844424c2 100644
--- a/kpresenter/slidetransitionwidget.ui
+++ b/kpresenter/slidetransitionwidget.ui
@@ -42,7 +42,7 @@
<verstretch>0</verstretch>
</sizepolicy>
</property>
- <property name="tqminimumSize">
+ <property name="minimumSize">
<size>
<width>240</width>
<height>180</height>
@@ -276,7 +276,7 @@
<property name="sizeType">
<enum>Expanding</enum>
</property>
- <property name="tqsizeHint">
+ <property name="sizeHint">
<size>
<width>20</width>
<height>29</height>
diff --git a/kpresenter/KPrTextObject.cpp b/kpresenter/KPrTextObject.cpp
index 6cec5fc2..54934755 100644
--- a/kpresenter/KPrTextObject.cpp
+++ b/kpresenter/KPrTextObject.cpp
@@ -1834,7 +1834,7 @@ void KPrTextView::paste()
TQCString returnedMimeType = KoTextObject::providesOasis( data );
if ( !returnedMimeType.isEmpty() )
{
- TQByteArray arr = data->tqencodedData( returnedMimeType );
+ TQByteArray arr = data->encodedData( returnedMimeType );
if ( arr.size() )
{
#if 0
@@ -1850,7 +1850,7 @@ void KPrTextView::paste()
}
else
{
// Note: TQClipboard::text() seems to do a better job than tqencodedData( "text/plain" )
// In particular it handles charsets (in the mimetype).
TQString text = TQApplication::tqclipboard()->text();
if ( !text.isEmpty() )
@@ -2379,7 +2379,7 @@ TQDragObject * KPrTextView::newDrag( TQWidget * parent )
KPrDocument * doc = kpTextObject()->kPresenterDocument();
- doc->getVariableCollection()->variableSetting()->setModificationDate( TQDateTime::tqcurrentDateTime() );
+ doc->getVariableCollection()->variableSetting()->setModificationDate( TQDateTime::currentDateTime() );
doc->recalcVariables( VT_DATE );
doc->recalcVariables( VT_TIME );
doc->recalcVariables( VT_STATISTIC );
@@ -2490,7 +2490,7 @@ void KPrTextView::dropEvent( TQDropEvent * e )
TQCString returnedTypeMime = KoTextObject::providesOasis( e );
if ( !returnedTypeMime.isEmpty() )
{
- TQByteArray arr = e->tqencodedData( returnedTypeMime );
+ TQByteArray arr = e->encodedData( returnedTypeMime );
if ( arr.size() )
{
KCommand *cmd = kpTextObject()->pasteOasis( cursor(), arr, false );
@@ -1850,7 +1850,7 @@ void KPrTextView::paste()
else
{
- // Note: TQClipboard::text() seems to do a better job than tqencodedData( "text/plain" )
+ // Note: TQClipboard::text() seems to do a better job than encodedData( "text/plain" )
// In particular it handles charsets (in the mimetype).
TQString text = TQApplication::tqclipboard()->text();